@@ -1,7 +1,7 @@
 # Copyright (c) 2004 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: CNic.pm,v 1.37 2006/01/09 10:44:54 gavin Exp $
+# $Id: CNic.pm,v 1.40 2006/05/02 15:57:01 gavin Exp $
 package WWW::CNic;
 use LWP;
 use LWP::ConnCache;
@@ -11,7 +11,7 @@ use Digest::MD5 qw(md5_hex);
 use vars qw($VERSION $CONNECTION_CACHE);
 use strict;
 
-our $VERSION = '0.16';
+our $VERSION = '0.18';
 
 =pod
 
@@ -222,6 +222,7 @@ sub execute {
 		$self->{_command} eq 'check_transfer'	&& return $self->_check_transfer();
 		$self->{_command} eq 'cancel_transfer'	&& return $self->_cancel_transfer();
 		$self->{_command} eq 'reactivate'	&& return $self->_reactivate_domain();
+		$self->{_command} eq 'push_domain'	&& return $self->_push_domain();
 		die("Invalid command '$self->{_command}'");
 	}
 }
@@ -667,6 +668,26 @@ sub _reactivate_domain {
 	return WWW::CNic::Response::ReactivateDomain->new($self->{_response}->{_raw});
 }
 
+sub _push_domain {
+	my $self = shift;
+	die("Missing username") if $self->{_username} eq '';
+	die("Missing password") if $self->{_password} eq '';
+	die("Missing domain")	if $self->{_domain}   eq '';
+	die("Missing handle")	if $self->{_handle}   eq '';
+	my %params = (
+				user		=> $self->{_username},
+				password	=> $self->_crypt_md5($self->{_password}),
+				test		=> $self->{_test},
+				domain		=> $self->{_domain},
+				handle		=> $self->{_handle},
+	);
+	my $url = "$self->{_base}/push_domain";
+	my $req = POST($url, \%params);
+	$self->{_response}->{_raw} = $self->_get($req);
+	use WWW::CNic::Response::PushDomain;
+	return WWW::CNic::Response::PushDomain->new($self->{_response}->{_raw});
+}
+
 sub _get {
 	my ($self, $request) = @_;
 	my $response = $self->{_agent}->request($request);
@@ -680,8 +701,8 @@ sub _get {
 sub _build_handle_string {
 	my ($self, $data) = @_;
 	my @str = ('new');
-	foreach my $key(qw(name company address postcode country phone fax email)) {
-		push(@str, ${$data}->{$key});
+	foreach my $key (qw(name company address postcode country phone fax email)) {
+		push(@str, $data->{$key});
 	}
 	return join("::", @str);
 }
