@@ -1,7 +1,7 @@
 # Copyright (c) 2006 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: Cookbook.pm,v 1.33 2006/01/09 10:46:22 gavin Exp $
+# $Id: Cookbook.pm,v 1.35 2006/05/02 15:57:01 gavin Exp $
 
 package WWW::CNic::Cookbook;
 use vars qw($VERSION);
@@ -595,10 +595,59 @@ status, and a registration or renewal invoice will be re-issed.
 		printf("Error: %s\n", $response->error);
 
 	}
-	
+
 If you specify an C<email> parameter, our administrators will send a notification
 to that address.
 
+=head2 Pushing a Domain Name To Another Reseller
+
+You may request that a domain name on your account be "pushed" to another
+reseller account. A domain name may only be pushed if:
+
+=over
+
+=item the domain name is on your account
+
+=item the domain name's status is "Live"
+
+=item the "gaining" reseller has not opted-out of the "push" system
+
+=back
+
+	my $query = WWW::CNic->new(
+		use_ssl		=> 1,
+		command		=> 'push_domain',
+		username	=> $handle,
+		password	=> $password,
+		domain		=> $domain,
+		handle		=> $gaining_handle_id,
+	);
+
+	my $response = $query->execute;
+
+	if ($response->is_success) {
+		print "Domain transferred OK.\n";
+
+	} else {
+		printf("Error: %s\n", $response->error);
+
+	}
+
+If the transaction is successful, the domain name will be immediately removed
+from your account. Any outstanding invoices will be credited to you and
+re-issued to the gaining account.
+
+If you are also listed as Technical Contact for the domain name, then this
+handle will also be changed to the gaining reseller account.
+
+This command will also transfer sponsorship of the client and/or technical
+handles for the domain name, but only if these handles are not associated with
+any other domains on your account. Where a handle is associated with domains on
+multiple reseller accounts, the handle becomes "unsponsored".
+
+We will send an e-mail to the gaining reseller notifying them of the domain
+transfer.
+
 =head1 Transferring Domain Names
 
 =head2 Starting a Domain Transfer
